// Persistence of Vision Ray Tracer Scene Description File
// File: appartement.inc
// Vers: 3.1
// Desc: appartement block 
// Date: 11.12.2001 
// Auth: M. Schneider 


// textures
// -----------------------------------------------------------------------

#declare Cement_T =
texture{
  pigment{
  crackle
  warp{turbulence <0.8, 0.4, 0.5>}
  color_map{[ 0 color rgb <0.6,0.6,0.6> ]
            [ 1 color rgb <0.7,0.7,0.7> ]}
  }
  normal{granite 0.1}
  finish{ambient 0 diffuse 0.8}
  scale 0.1
}

#declare Level_T =
texture{
  pigment{
    brick color rgb <0.3, 0.3, 0.3>, color rgb <0.905882, 0.658824, 0.239216>
    brick_size <0.25, 0.1, 0.2>
    mortar 0.025 
  }
  normal{brick 0.08 brick_size <0.25, 0.1, 0.2> mortar 0.025}
  finish{ambient 0 diffuse 0.8}  
}

#declare Glass_T =
texture{
  pigment{Clear}
  finish{ambient 0 diffuse 0 brilliance 0.5 phong 0.2 phong_size 100 
    specular 1 reflection 0.1 roughness 0.001}      
}
 
 
// basement, level and roof
// -----------------------------------------------------------------------

#declare BasementHeight = 3;
#declare LevelHeight = 2.5;

#declare Basement =
merge{
  difference{
    box{ // basement
      <-5, 0, -2>
      < 5, BasementHeight,  2>
    }
    box{ // door
      <-4, -0.1, -2.1>
      <-2.5, 2.8, 0>
    }
    box{ // window
      <-2, 1.2, -2.1>
      <-0.5, 2.7, 0>
      pigment{color White}
    }
    box{ // window
      <0.5, 1.2, -2.1>
      <2, 2.7, 0>
      pigment{color White}
    }
    box{ // window  
      <3, 1.2, -2.1>
      <4.5, 2.7, 0>
      pigment{color White}
    }
    #ifdef(textured) texture{Cement_T} #else pigment{color White} #end
  }
 
 difference{ // door left
   box{
     <-4, 0, -2>
     <-3.25, 2.8, -1.7>
     #ifdef(textured) texture{T_Wood8 scale 0.2} #else pigment{color White} #end
   }
   box{
     <-3.9, 0.1, -2.1>
     <-3.35, 2.7, -1.9>
     #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
       #else pigment{color White} #end
   }   
 }
 
 difference{ // door right
   box{
     <-3.25, 0, -2>
     <-2.5, 2.8, -1.7>
     #ifdef(textured) texture{T_Wood8 scale 0.2 translate <5, 0 ,0>} #else pigment{color White} #end
   }
   box{
     <-3.15, 0.1, -2.1>
     <-2.6, 2.7, -1.9>
     #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
       #else pigment{color White} #end
   }
 }
 
 box{ // window glass
   <-1.99, 1.19, -2>
   <-0.51, 2.69, -1.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
 }

 box{ // window glass
   <0.49, 1.19, -2>
   <1.99, 2.69, -1.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
 }

 box{ // window glass
   <3.01, 1.19, -2>
   <4.49, 2.69, -1.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
 }
}

#declare Level =
merge{
  difference{
    box{ // level
      <-5, 0, -3>
      <5, LevelHeight, 3>
    }
    box{ // window
      <-4.75, 1.25, -3.1>
      <-2.75, 2.4, 0>
      pigment{color White}
    }
    box{ // window
      <-2.25, 1.25, -3.1>
      <-0.25, 2.4, 0>
      pigment{color White}
    }
    box{ // window
      <0.25, 1.25, -3.1>
      <2.25, 2.4, 0>
      pigment{color White}
    }
    box{ // window
      <2.75, 1.25, -3.1>
      <4.75, 2.4, 0>
      pigment{color White}
    }
    #ifdef(textured) texture{Level_T} #else pigment{color White} #end
  }

  box{ // balcony
    <-2, 0.5, -3.5>
    <-0.25, 1.2, -3>
    #ifdef(textured) texture{Cement_T} #else pigment{color White} #end     
  }
  
  box{ // balcony
    <3, 0.5, -3.5>
    <4.75, 1.2, -3>
    #ifdef(textured) texture{Cement_T} #else pigment{color White} #end     
  }
  
  box{ // window glass
    <-4.74, 1.26, -3>
    <-2.76, 2.39, -2.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }

  box{ // window glass
      <-2.24, 1.26, -3>
      <-0.26, 2.39, -2.9>  
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }

  box{ // window glass
    <0.26, 1.26, -3>
    <2.24, 2.39, -2.9>  
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }

  box{ // window glass
    <2.76, 1.26, -3>
    <4.74, 2.39, -2.9>  
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }      
}

#declare Roof =
box{
  <-5, 0, -3.2>
  <5, 0.1, 3.2>
  #ifdef(textured) texture{Cement_T} #else pigment{color White} #end
}

#macro Appartement(Levels) 
merge{
  object{ Basement }
  
  #local i = 0;
  #while(i < Levels)
    object{ Level translate y*(BasementHeight + i*LevelHeight) }
    #local i = i+1;
  #end  
  object{ Roof translate y*(BasementHeight + i*LevelHeight) }  
}
#end
