// Persistence of Vision Ray Tracer Scene Description File
// File: market.pov
// Vers: 3.1
// Desc: asian market street
// Date: 11.12.2001 
// Auth: M. Schneider

// ==== Standard POV-Ray Includes ====
#include "colors.inc"	// Standard Color definitions
#include "textures.inc"	// Standard Texture definitions
#include "woods.inc"

#version unofficial MegaPov 0.7;

#declare textured = true;
//#declare ShowTree = true;
#declare FogOn = true;
#declare Area_LightOn = true;
#declare RadiosityOn = true;

#include "street.inc"
#include "appartement.inc"
#include "restaurant.inc"
#include "table.inc"
#include "umbrella.inc"
#include "grass.inc"
#include "melon.inc"
#include "CokeCan.inc"
#include "dog.pov"
#include "bicycle.inc"

#include "txttree.inc" // for the tree macro

                         
// environment and camera
// -----------------------------------------------------------------------
  
#ifdef(FogOn)  
  fog{
    distance 65
    color rgbt <0.9, 0.9, 0.9, 0.5>
    turbulence 0.2
    turb_depth 0.3
  }
#end

sky_sphere{
  #ifdef(textured)
    pigment{
      bozo
      turbulence 0.75
      octaves 8
      lambda 2.4
      omega 0.6 
      color_map{[ 0.0 color Blue ]
                [ 0.7 color White]}
    }
    scale <2.5, 1, 1>  
  #else
    pigment{color White}
  #end
}

light_source{
  <5, 300, -20>
  color rgb <1.0, 0.984314, 0.866667>*1.5 // use 5, if radiosity turned on set to 1.5
  //color White 
  //shadowless
  #ifdef(Area_LightOn)
    area_light x,z,4,4
    adaptive 1
    jitter
    circular
  #end
}

light_source{
  <3, 4,  1>
  color rgb <1.0, 0.984314, 0.866667>*0.5
  shadowless
}  
  
#ifdef(RadiosityOn)
global_settings{
  ini_option "+QR"
  radiosity{             // medium quality for most scenes
    pretrace_start 0.08
    pretrace_end   0.04
    count 35             // CHANGE range from 20 to 150
    nearest_count 5      // CHANGE range from 3 to 10
    error_bound 1.8      // CHANGE - range from 1 to 3 - should correspond with pretrace_end
                         //   1 : pretrace_end = 0.02
                         //   3 : pretrace_end = 0.08
                         //   use pretrace_start = 0.08
                         // you can go lower than 1, but then you probably will want to set
                         // pretrace_end to 0.01, which is really slow
    recursion_limit 3    // CHANGE
    
    low_error_factor .5  // leave this
    gray_threshold 0.0   // leave this
    minimum_reuse 0.015  // leave this
    brightness 1         // leave this
    
    adc_bailout 0.01/2   // CHANGE - use adc_bailout = 0.01 / brightest_ambient_object
  }
}
#end

#declare Scene = 
camera{ // 9:13 ratio, command line: +W180 +H260
  location <2.5, 1.8, -1.5>
  //up <0,1,0>
  //right <9/13, 0, 0>  
  look_at <1.2, 2.0, 3.0>
}  

#declare TableDetail =
camera{
  location <1.0, 1.4, 3.0>
  look_at <-1.0,0.9, 3.0> 
}
  
#declare TopView =
camera{
  location <0, 25, 10>
  look_at <0, 0, 10>
}  
  
camera{ Scene }


// scenery
// -----------------------------------------------------------------------
       
// street ----------------------------------------------------------------       
object{
  Street
}

object{
  Street
  translate <0, 0, 50>
}

// appartements ----------------------------------------------------------
object{
  Appartement(5)
  rotate y*-90
  translate <-7, 0, 5>
}

object{
  Appartement(5)
  rotate y*-90
  translate <-7, 0, 15>
}

object{
  Appartement(4)
  rotate y*-90
  translate <-7, 0, 30>
}

// restaurants -----------------------------------------------------------
object{
  Restaurant(4)
  rotate y*90
  translate <7, 0, 2>
}

object{
  Restaurant(4)
  rotate y*90
  translate <7, 0, 17>
}

// tables, left side -----------------------------------------------------
object{
  Table
  rotate y*-90
  translate <-1.5, -0.1, 3>
}

#local m_pos = 2.0;
#local ry = seed(827);
#while(m_pos < 4.0)
  object{
    Watermelon
    rotate y*(rand(ry)-0.5)*110
    translate <-1.5, 0.8, m_pos>
  }
  #local m_pos = m_pos+0.25;
#end

object{
  Table
  rotate y*-90
  translate <-1.5, -0.1, 8>
}

// tables, right side ----------------------------------------------------     
object{
  Table
  rotate y*-90
  translate <1.5, -0.1, 5>
}

object{
  Table
  rotate y*-90
  translate <1.5, -0.1, 15>
}

// umbrella, left side ---------------------------------------------------
object{
  Umbrella
  scale 0.2
  translate <-1.3, -0.1, 5.5>
}

object{
  Umbrella
  scale 0.2
  rotate <0, 90, 0>
  translate <-1.3, -0.1, 10.5>
}

// umbrella , right side -------------------------------------------------
object{
  Umbrella
  scale 0.2
  rotate <0, -90, 0>
  translate <1.3, -0.1, 17.5>
}
                   
// coke can --------------------------------------------------------------        
object{
  CokeCan
  scale 1/20
  rotate <0, 0, 90>
  translate <1.7, -0.05 ,3>
}

// dog -------------------------------------------------------------------
object{ 
  dog
  scale 0.1    
  rotate<0, 0, 0> 
  translate<1.0, -0.1, 2.5>  
}

// grass -----------------------------------------------------------------
#local i = 0;
#local r1 = seed(3875);
#while(i < 100)
  object{
    Grass
    scale 0.1
    rotate <0, rand(r1)*360, 0>
    translate <-3.0+(rand(r1)-0.5)*2.0, 0, 4.0+(rand(r1)-0.5)*9.0>
  }
  #local i = i+1;
#end
  
// tree ------------------------------------------------------------------  
#ifdef(ShowTree)
  #declare txtTree=texture{txtTree_3}
  #declare txtLeaf=texture{txtLeaf_3}
  #declare Leaf = object{#include "myLeaf.inc"} 
  #declare Tree1 = object{#include "myTree.inc"}
  #declare Foliage1=object{#include "myFoliage.inc"
          texture{txtLeaf} 
  }
  union{
       object{Tree1}
       object{Foliage1}
       scale 1/6
       translate <2.6, 0, 9>
  }
#end

// bicycle ---------------------------------------------------------------
object{
  Bicycle
  scale 1/95
  rotate <10, -30, 0>
  translate <2.8, 0.65, 8>
}