// Persistence of Vision Ray Tracer Scene Description File
// File: restaurant.inc
// Vers: 3.1
// Desc: restaurant
// Date: 15.12.2001
// Auth: M. Schneider

#version unofficial MegaPov 0.7;

// textures
// -----------------------------------------------------------------------

#declare Level1_T =
texture{
  pigment{
    brick color rgb <0.3, 0.3, 0.3>, color rgb <0.792157, 0.870588, 0.92549>
    brick_size <0.25, 0.1, 0.2>
    mortar 0.025 
  }
  normal{brick 0.08 brick_size <0.25, 0.1, 0.2> mortar 0.025}
  finish{ambient 0 diffuse 0.8 specular 0.1 roughness 0.009 reflection 0.1}  
}

#declare RestaurantAd_T =
texture{
  pigment{
    image_map{png "RedPlate.png" interpolate 2}
  }
  normal{
    bump_map{png "RedPlateBump.png" interpolate 2 bump_size 2.0}
  }
  finish{ambient 0 diffuse 0.5 metallic specular 0.5 roughness 0.01} 
/*  rotate y*90
  scale <1, 2.1, 0.4>
  translate <0, 2.9, 0.1> */
}


// basement, level and roof
// -----------------------------------------------------------------------

#declare Basement1Height = 3;
#declare Level1Height = 2.5;

#declare Basement1 =
merge{
  difference{
    box{ // basement
      <-5, 0, -2>
      < 5, Basement1Height,  2>
    }
    box{ // door
      <-4, -0.1, -2.1>
      <-2.5, 2.8, 0>
    }
    box{ // window
      <-2, 1.2, -2.1>
      <-0.5, 2.7, 0>
      pigment{color White}
    }
    box{ // window
      <0.5, 1.2, -2.1>
      <2, 2.7, 0>
      pigment{color White}
    }
    box{ // window  
      <3, 1.2, -2.1>
      <4.5, 2.7, 0>
      pigment{color White}
    }
    #ifdef(textured) texture{Cement_T} #else pigment{color White} #end
  }
 
 difference{ // door left
   box{
     <-4, 0, -2>
     <-3.25, 2.8, -1.7>
     #ifdef(textured) texture{T_Wood8 scale 0.2} #else pigment{color White} #end
   }
   box{
     <-3.9, 0.1, -2.1>
     <-3.35, 2.7, -1.9>
     #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
       #else pigment{color White} #end
   }   
 }
 
 difference{ // door right
   box{
     <-3.25, 0, -2>
     <-2.5, 2.8, -1.7>
     #ifdef(textured) texture{T_Wood8 scale 0.2 translate <5, 0 ,0>} #else pigment{color White} #end
   }
   box{
     <-3.15, 0.1, -2.1>
     <-2.6, 2.7, -1.9>
     #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
       #else pigment{color White} #end
   }
 }
 
 box{ // window glass
   <-1.99, 1.19, -2>
   <-0.51, 2.69, -1.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
 }

 box{ // window glass
   <0.49, 1.19, -2>
   <1.99, 2.69, -1.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
 }

 box{ // window glass
   <3.01, 1.19, -2>
   <4.49, 2.69, -1.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
 }
}

#declare Level1 =
merge{
  difference{
    box{ // level
      <-5, 0, -3>
      <5, Level1Height, 3>
    }
    box{ // window
      <-4.75, 1.25, -3.1>
      <-2.75, 2.4, 0>
      pigment{color White}
    }
    box{ // window
      <-2.25, 1.25, -3.1>
      <-0.25, 2.4, 0>
      pigment{color White}
    }
    box{ // window
      <0.25, 1.25, -3.1>
      <2.25, 2.4, 0>
      pigment{color White}
    }
    box{ // window
      <2.75, 1.25, -3.1>
      <4.75, 2.4, 0>
      pigment{color White}
    }
    #ifdef(textured) texture{Level1_T} #else pigment{color White} #end
  }
  
  union{
    box{ // balcony
      <-2, 0.5, -3.5>
      <-0.25, 1.2, -3>
    }
    cylinder{
      <-2, 0.5, -3>
      <-2, 1.2, -3>
      0.5
    }
    cylinder{
      <-0.25, 0.5, -3>
      <-0.25, 1.2, -3>
      0.5
    }  
    #ifdef(textured) texture{Cement_T} #else pigment{color White} #end 
  }  
  
  union{
    box{ // balcony
      <3, 0.5, -3.5>
      <4.75, 1.2, -3>         
    }
    cylinder{
      <3, 0.5, -3>
      <3, 1.2, -3>
      0.5
    }
    cylinder{
      <4.75, 0.5, -3>
      <4.75, 1.2, -3>
      0.5
    }    
    #ifdef(textured) texture{Cement_T} #else pigment{color White} #end
  }  
  
  box{ // window glass
    <-4.74, 1.26, -3>
    <-2.76, 2.39, -2.9>
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }

  box{ // window glass
      <-2.24, 1.26, -3>
      <-0.26, 2.39, -2.9>  
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }

  box{ // window glass
    <0.26, 1.26, -3>
    <2.24, 2.39, -2.9>  
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }

  box{ // window glass
    <2.76, 1.26, -3>
    <4.74, 2.39, -2.9>  
   #ifdef(textured) texture{Glass_T} interior{ior 1.5 caustics 1.0} 
     #else pigment{color White} #end
  }
      
}

#declare Roof1 =
box{
  <-5, 0, -3.2>
  <5, 0.1, 3.2>
  #ifdef(textured) texture{Cement_T} #else pigment{color White} #end
}

#declare RestaurantAd =
merge{
  box{
    <-4.9, Basement1Height, -4.1>
    <-4.89, 2*Level1Height, -3.1>
    #ifdef(textured) uv_mapping texture{RestaurantAd_T} #else pigment{color White} #end
  }
  cylinder{
    <-4.9, Basement1Height+0.3, -3.1>
    <-4.9, Basement1Height+0.3, -2.9>
    0.01
    pigment{color White}
  }
  cylinder{
    <-4.9, 2*Level1Height-0.3, -3.1>
    <-4.9, 2*Level1Height-0.3, -2.9>
    0.01
    pigment{color White}
  }      
}

#macro Restaurant(Levels) 
merge{
  object{ Basement1 }
  
  #local i = 0;
  #while(i < Levels)
    object{ Level1 translate y*(Basement1Height + i*Level1Height) }
    #local i = i+1;
  #end  
  object{ Roof1 translate y*(Basement1Height + i*Level1Height) }  
  object{ RestaurantAd }
}
#end
