// Persistence of Vision Ray Tracer Scene Description File
// File: street.inc
// Vers: 3.1
// Desc: market street
// Date: 11.12.2001
// Auth: M. Schneider 


// textures
// -----------------------------------------------------------------------

#declare Kerb_T = 
texture{
  pigment{
    crackle 
    color_map{[ 0 rgb <0.811490, 0.713359, 0.608484> ]
              [ 1 rgb <0.884993, 0.777646, 0.654978> ]}
  }
  normal{granite 0.6}
  finish{ambient 0 diffuse 0.8}
  scale 0.3
}

#declare Street_T =
texture{
  pigment{
    crackle
    warp{turbulence <0.2, 0.5, 0.7>}
    color_map{[ 0 color rgb <0.3,0.3,0.3> ]
              [ 1 color rgb <0.5,0.5,0.5> ]}         
  }
  normal{granite 0.1}
  finish{ambient 0 diffuse 0.5}
  scale 0.1           
}
                      
#declare SewerCap_T =
texture{
  pigment{
    bozo
    color_map{[ 0 color rgb <0.2,0.2,0.2> ]
              [ 1 color rgb <0.4,0.4,0.4> ]}
  }
  normal{bumps 0.1}
  finish{ambient 0.1 phong 0.5 phong_size 10 diffuse 0.4}
  scale 0.1
}

#declare SewerCement_T =
texture{
  pigment{
  crackle
  warp{turbulence <0.8, 0.4, 0.5>}
  color_map{[ 0 color rgb <0.5,0.5,0.5> ]
            [ 1 color rgb <0.6,0.6,0.6> ]}
  }
  normal{granite 0.1}
  finish{ambient 0 diffuse 0.8}
  scale 0.2
}
 
  
// sewer
// -----------------------------------------------------------------------

#declare Sewer =
merge{
  superellipsoid{
    <0.1, 0.1>
    scale <0.3, 0.05, 0.3>
    translate y*-0.025
    #ifdef(textured) texture{SewerCement_T} #else pigment{color Blue} #end
  }

  difference{
    box{
      <-0.25, -0.05, -0.25>
      <0.25, 0.05, 0.25>
    }
    box{
      <-0.23, 0.03, -0.23>
      <0.23, 0.051, 0.23>
    }
    #ifdef(textured) texture{SewerCap_T} #else pigment{color Grey} #end
  }  
}

// power line
// -----------------------------------------------------------------------

#declare PowerLine =
union{
  cone{
    <1.8, -0.1, 25>, 0.1
    <1.8, 15, 25>, 0.05
  }
  cylinder{
    <1.3, 15, 25>
    <2.3, 15, 25>
    0.05
  }
  #ifdef(textured) texture{SewerCement_T} #else pigment{color Blue} #end  
}

// street, pavement and kerbs
// -----------------------------------------------------------------------

#declare Street = 
merge{
#local StreetLength = 50.0;
  difference{
    box{ // pavement
      <-10, -0.2, 0>
      < 10, 0, StreetLength>
    }
    box{ // street
      <-2, -0.1, 0>
      < 2, 0.01, StreetLength>
    }
    #ifdef(textured) texture{Street_T} #else pigment{color White} #end
  }

  #local KerbLength = 2.0;
  #local nKerbs = StreetLength/KerbLength;
  #local i = 0.0;
  #local zPos = 1.0;
  #local KerbShape = 0.1;
  #local R1 = seed(1234);

  #while(i < nKerbs)
    superellipsoid{ // left kerb
      <0.3, 0.3>
      scale<KerbShape, KerbShape, KerbLength>
      translate <-2+(rand(R1)-0.5)*0.12, -0.099, zPos>
      #ifdef(textured) texture{Kerb_T} #else pigment{color Grey} #end
    }
    superellipsoid{ // right kerb
      <0.3, 0.3>
      scale<KerbShape, KerbShape, KerbLength>
      translate <2+(rand(R1)-0.5)*0.12, -0.099, zPos>
      #ifdef(textured) texture{Kerb_T} #else pigment{color Grey} #end      
    }    
    //#debug concat(str(zPos,0,3),"\n")
    #local i = i+1.0;
    #local zPos = zPos+KerbLength+0.01;  
  #end
  
  object{
    Sewer
    translate <2.4, 0, 1>
    }
  object{
    Sewer
    translate <2.4, 0, 6>
    }
  object{
    Sewer
    translate <2.4, 0, 11>
    }
    
  object{
    PowerLine
  }    
}
